Fonts: Caladea
==============

Caladea is a hand-drawn font by Carolina Giovagnoli and Andres Torresi released under the Apache 2.0 License.

Preview: https://fontlibrary.org/en/font/caladea

This font has been repackaged for the Python Fonts module: https://pypi.org/project/fonts/

Copyright, Carolina Giovagnoli and Andres Torresi. Redistributed under the terms of the Apache 2.0 License: http://www.apache.org/licenses/LICENSE-2.0
